==> istio-model-v1beta1-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<A extends LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent() {
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent(LoadBalancerSettingsConsistentHashLBHttpCookieValue instance) {
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBHttpCookieValue());

    if (instance != null) {
      this.withName(instance.getName());
      this.withPath(instance.getPath());
      this.withTtl(instance.getTtl());
      this.withName(instance.getName());
      this.withPath(instance.getPath());
      this.withTtl(instance.getTtl());
    }
  }
  private String name;
  private String path;
  private String ttl;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public boolean hasPath() {
    return this.path != null;
  }
  public String getTtl() {
    return this.ttl;
  }
  public A withTtl(String ttl) {
    this.ttl=ttl; return (A) this;
  }
  public boolean hasTtl() {
    return this.ttl != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent that = (LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(path, that.path)) return false;

    if (!java.util.Objects.equals(ttl, that.ttl)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  path,  ttl,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (ttl != null) { sb.append("ttl:"); sb.append(ttl); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<A extends LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent() {
  }
  
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent(LoadBalancerSettingsConsistentHashLBHttpCookieValue instance) {
    this.copyInstance(instance);
  }
  private String name;
  private String path;
  private String ttl;
  
  protected void copyInstance(LoadBalancerSettingsConsistentHashLBHttpCookieValue instance) {
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBHttpCookieValue());
  
    if (instance != null) {
        this.withName(instance.getName());
        this.withPath(instance.getPath());
        this.withTtl(instance.getTtl());
        this.withName(instance.getName());
        this.withPath(instance.getPath());
        this.withTtl(instance.getTtl());
      }
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getPath() {
    return this.path;
  }
  
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  
  public boolean hasPath() {
    return this.path != null;
  }
  
  public String getTtl() {
    return this.ttl;
  }
  
  public A withTtl(String ttl) {
    this.ttl=ttl; return (A) this;
  }
  
  public boolean hasTtl() {
    return this.ttl != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent that = (LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(path, that.path)) return false;
  
    if (!java.util.Objects.equals(ttl, that.ttl)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(name,  path,  ttl,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (ttl != null) { sb.append("ttl:"); sb.append(ttl); }
    sb.append("}");
    return sb.toString();
  }
  

}
